@@ -53,7 +53,7 @@ const kXHTML_TRANSITIONAL = "resource://app/res/xhtml_transitional.xhtml";
 const kXHTML_STRICT = "resource://app/res/xhtml_strict.xhtml";
 const kHTML5 = "resource://app/res/html5.html";
 const kXHTML5 = "resource://app/res/xhtml5.xhtml";
-//@line 51 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 51 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 // implements nsIObserver
 var gEditorDocumentObserver =
@@ -273,11 +273,12 @@ var BlueGriffonPrefsObserver = {
   }
 };
 
-//@line 53 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 53 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 Components.utils.import("resource://app/modules/urlHelper.jsm");
 Components.utils.import("resource://app/modules/editorHelper.jsm");
 Components.utils.import("resource://app/modules/bgQuit.jsm");
+Components.utils.import("resource://gre/modules/AddonManager.jsm");
 
 var gContentWindow = null;
 
@@ -333,6 +334,12 @@ function Startup()
 
   setTimeout(LoadLastTabs, 1000);
   BlueGriffonQuitHelper.init();
+
+  AddonManager.getAddonByID("{f13b157f-b174-47e7-a34d-4815ddfdfeb8}",
+    function(addon) { if(addon) document.getElementById("venkmanMenuitem").hidden = false; } );
+
+  AddonManager.getAddonByID("inspector@mozilla.org",
+    function(addon) { if(addon) document.getElementById("menu_inspector").hidden = false; } );
 }
 
 var gLastTabsArray;
@@ -365,7 +372,7 @@ function OpenTabFromPreviousSession(aReason, aContext)
   }
 }
 
-//@line 55 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 55 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 function Shutdown()
 {
@@ -403,7 +410,7 @@ function onClose()
     return true;
   }
   return false;
-}//@line 57 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+}//@line 57 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function OpenLocation(aEvent, type)
@@ -514,7 +521,7 @@ function AboutComposer()
   var enumerator = wm.getEnumerator( "BlueGriffon:About" );
   while ( enumerator.hasMoreElements() )
   {
-    var win = enumerator.getNext().QueryInterface(Components.interfaces.nsIDOMWindowInternal);
+    var win = enumerator.getNext().QueryInterface(Components.interfaces.nsIDOMWindow);
     win.focus();
     return;
   }
@@ -893,6 +900,50 @@ function ShowLanguageDialog(aEvent)
   }
 }
 
+function UpdateDirectionMenu(aEvent)
+{
+  var popupNode = document.popupNode;
+  if (popupNode)
+  {
+    var target = popupNode.getUserData("node");
+    if (target) {
+      var direction = target.style.direction;
+      switch (direction) {
+        case "ltr":
+          gDialog.noDirectionContextMenuitem.removeAttribute("checked");
+          gDialog.ltrDirectionContextMenuitem.setAttribute("checked", "true");
+          gDialog.rtlDirectionContextMenuitem.removeAttribute("checked");
+          break;
+        case "rtl":
+          gDialog.noDirectionContextMenuitem.removeAttribute("checked");
+          gDialog.ltrDirectionContextMenuitem.removeAttribute("checked");
+          gDialog.rtlDirectionContextMenuitem.setAttribute("checked", "true");
+          break;
+        default:
+          gDialog.noDirectionContextMenuitem.setAttribute("checked", "true");
+          gDialog.ltrDirectionContextMenuitem.removeAttribute("checked");
+          gDialog.rtlDirectionContextMenuitem.removeAttribute("checked");
+          break;
+      }
+    }
+  }
+}
+
+function SetDirection(aEvent)
+{
+  var value = aEvent.originalTarget.getAttribute("value");
+  var popupNode = document.popupNode;
+  if (popupNode)
+  {
+    var target = popupNode.getUserData("node");
+    if (target) {
+      var txn = new diStyleAttrChangeTxn(target, "direction", value, "");
+      EditorUtils.getCurrentEditor().transactionManager.doTransaction(txn);
+      EditorUtils.getCurrentEditor().incrementModificationCount(1);  
+    }
+  }
+}
+
 function DeleteElement(aEvent)
 {
   var popupNode = document.popupNode;
@@ -937,7 +988,7 @@ function ExplodeElement(aEvent)
 
 function ChangeTag(aEvent)
 {
-  var popupNode = document.popupNode;
+  var popupNode = gDialog.structurebar.querySelector("[checked='true']");
   var textbox = document.createElement("textbox");
   textbox.setAttribute("value", popupNode.getAttribute("value"));
   textbox.setAttribute("width", popupNode.boxObject.width);
@@ -1055,9 +1106,24 @@ function ToggleViewMode(aElement)
     const nsIDE = Components.interfaces.nsIDocumentEncoder;
     var flags = nsIDE.OutputFormatted ;
     flags |= nsIDE.OutputWrap;
-    flags |= nsIDE.OutputLFLineBreak;
     flags |= nsIDE.OutputPersistNBSP;
 
+    var osString = Components.classes["@mozilla.org/xre/app-info;1"]
+                     .getService(Components.interfaces.nsIXULRuntime).OS;
+    switch (osString) {
+      case "WINNT":
+        flags |= nsIDE.OutputLFLineBreak;
+        flags |= nsIDE.OutputCRLineBreak;
+        break;
+      case "Darwin":
+        flags |= nsIDE.OutputCRLineBreak;
+        break;
+      case "Linux":
+      default:
+        flags |= nsIDE.OutputLFLineBreak;
+        break;
+    }
+
     var encodeEntity = GetPrefs().getCharPref("bluegriffon.source.entities");
     switch (encodeEntity) {
       case "basic"  : flags |= nsIDE.OutputEncodeBasicEntities;     break;
@@ -1250,7 +1316,7 @@ function doCloseTab(aTab)
   }
   window.updateCommands("style");
   NotifierUtils.notify("tabClosed");
-//@line 908 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 967 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 }
 
 function SetLocationDB()
@@ -1524,6 +1590,15 @@ function OnDoubleClick(aEvent)
       if (EditorUtils.getCurrentEditor().selection.isCollapsed)
         OpenAppModalWindow(window, "chrome://bluegriffon/content/dialogs/insertTable.xul", "Tables", false, node); 
       break;
+    case "li":
+    case "ul":
+    case "ol":
+      {
+        var selContainer = EditorUtils.getSelectionContainer();
+        if (selContainer.oneElementSelected)
+          cmdEditListCommand.doCommand();
+      }
+      break;
     default:
       if (node.namespaceURI == "http://www.w3.org/2000/svg")
       {
@@ -1560,6 +1635,12 @@ function onBespinLineKeypress(aEvent, aElt)
     onBespinLineBlur(aElt);
     onBespinFocus(EditorUtils.getCurrentSourceEditorElement());
   }
+  if (aEvent.keyCode == 13 ||
+      (aEvent.keyCode == 27 && !aEvent.which)) { // ESC key
+    gDialog.bespinToolbox1.hidden = true;
+    gDialog.bespinToolbox2.hidden = true;
+    EditorUtils.getCurrentSourceEditorElement().focus();
+  }
 }
 
 function ToggleBespinFindCaseSensitivity()
@@ -1701,21 +1782,21 @@ function BespinKeyPressCallback(aEvent)
         break;
       /*case 99: // meta-c XXX Workaround for Copy horked in Bespin0.9+Gecko2
       case 120: // meta-x XXX
-	      {
-	        aEvent.preventDefault();
+        {
+          aEvent.preventDefault();
           var bespinEditor = EditorUtils.getCurrentSourceEditor();
           var selection = bespinEditor.selectedText;
-	        var clipboardSvc = Components.classes["@mozilla.org/widget/clipboard;1"].
-	                           getService(Components.interfaces.nsIClipboard);
-	        var xferable = Components.classes["@mozilla.org/widget/transferable;1"].
-	                       createInstance(Components.interfaces.nsITransferable);
+          var clipboardSvc = Components.classes["@mozilla.org/widget/clipboard;1"].
+                             getService(Components.interfaces.nsIClipboard);
+          var xferable = Components.classes["@mozilla.org/widget/transferable;1"].
+                         createInstance(Components.interfaces.nsITransferable);
           xferable.addDataFlavor("text/unicode");
-			    var s = Components.classes["@mozilla.org/supports-string;1"].
-			            createInstance(Components.interfaces.nsISupportsString);
-			    s.data = selection;
+          var s = Components.classes["@mozilla.org/supports-string;1"].
+                  createInstance(Components.interfaces.nsISupportsString);
+          s.data = selection;
           xferable.setTransferData("text/unicode", s, selection.length * 2);
           clipboardSvc.setData(xferable, null, Components.interfaces.nsIClipboard.kGlobalClipboard);
-	      }
+        }
         if (aEvent.which == 120)
           bespinEditor.selectedText = "";
         break;*/
@@ -1873,7 +1954,7 @@ function ReplaceInWysiwyg()
   return true;
 }
 
-//@line 1200 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1268 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var AutoInsertTable = {
@@ -1909,66 +1990,66 @@ var AutoInsertTable = {
   },
 
   selectArea: function(cell)
-	{
-	  var cellID    = cell.id;
+  {
+    var cellID    = cell.id;
     var r = cellID.match ( /AutoInsertTable_r([0-9]*)c([0-9]*)/ );
 
-	  var row = r[1];
+    var row = r[1];
     var column = r[2];
-	
-	  // early way out if we can...
-	  if (this.mRow == row && this.mColumn == column)
-	    return;
-	
-	  this.mRow = row;
+  
+    // early way out if we can...
+    if (this.mRow == row && this.mColumn == column)
+      return;
+  
+    this.mRow = row;
     this.mColumn = column;
-	
-	  var cells = gDialog.AutoInsertTableSizeSelector.querySelectorAll("label");
+  
+    var cells = gDialog.AutoInsertTableSizeSelector.querySelectorAll("label");
     for (var i = 0; i < cells.length; i++)
       cells[i].className = "";
-	
-	  for (i = row; i > 0; i--)
-	  {
-	    anyCell = document.getElementById("AutoInsertTable_r"+i+"c"+this.mColumn);
-	    while (anyCell)
-	    {
-	      anyCell.setAttribute("class", "selected");
-	      anyCell = anyCell.previousSibling;
-	    }
-	  }
+  
+    for (i = row; i > 0; i--)
+    {
+      anyCell = document.getElementById("AutoInsertTable_r"+i+"c"+this.mColumn);
+      while (anyCell)
+      {
+        anyCell.setAttribute("class", "selected");
+        anyCell = anyCell.previousSibling;
+      }
+    }
     gDialog.AutoInsertTableSizeLabel.value = this.mRow + " x " + this.mColumn;
-	},
+  },
 
   selectSize: function(cell)
-	{
-	  gDialog.AutoInsertTableSheetPopup.hidePopup();
-	
-	  var editor = EditorUtils.getCurrentEditor();
-	  var doc = EditorUtils.getCurrentDocument();
-	  editor.beginTransaction();
-	  var tableElement = doc.createElement("table");
-	  var tableBody = doc.createElement("tbody");
-	  tableElement.appendChild(tableBody);
-	  tableElement.setAttribute("border", "1");
-	  tableElement.setAttribute("width", "100%");
-	  var firstCell = null;
-	  for (var i = 0; i < this.mRow; i++)
-	  {
-	    var newRow = doc.createElement("tr");
-	    tableBody.appendChild(newRow);
-	    for (var j = 0; j < this.mColumn; j++)
-	    {
-	      var newCell = doc.createElement("td");
-	      if (!firstCell)
-	        firstCell = newCell;
-	      newRow.appendChild(newCell);
-	    }
-	  }
-	  editor.insertElementAtSelection(tableElement, true);
-	  editor.endTransaction();
-	  editor.selection.collapse(firstCell, 0);
-	  window.content.focus();
-	},
+  {
+    gDialog.AutoInsertTableSheetPopup.hidePopup();
+  
+    var editor = EditorUtils.getCurrentEditor();
+    var doc = EditorUtils.getCurrentDocument();
+    editor.beginTransaction();
+    var tableElement = doc.createElement("table");
+    var tableBody = doc.createElement("tbody");
+    tableElement.appendChild(tableBody);
+    tableElement.setAttribute("border", "1");
+    tableElement.setAttribute("width", "100%");
+    var firstCell = null;
+    for (var i = 0; i < this.mRow; i++)
+    {
+      var newRow = doc.createElement("tr");
+      tableBody.appendChild(newRow);
+      for (var j = 0; j < this.mColumn; j++)
+      {
+        var newCell = doc.createElement("td");
+        if (!firstCell)
+          firstCell = newCell;
+        newRow.appendChild(newCell);
+      }
+    }
+    editor.insertElementAtSelection(tableElement, true);
+    editor.endTransaction();
+    editor.selection.collapse(firstCell, 0);
+    window.content.focus();
+  },
 
   increaseSize: function(aX, aY)
   {
@@ -2008,7 +2089,7 @@ var AutoInsertTable = {
     }
   }
 };
-//@line 1202 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1270 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function AlignAllPanels()
@@ -2019,9 +2100,9 @@ function AlignAllPanels()
 
 function UpdatePanelsStatusInMenu()
 {
-//@line 1214 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1282 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1217 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1285 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var child = gDialog.beforeAllPanelsMenuseparator.nextSibling;
   while (child) {
     var panel = gDialog[child.getAttribute("panel")];
@@ -2036,10 +2117,9 @@ function UpdatePanelsStatusInMenu()
 
 function TogglePanel(aEvent)
 {
-//@line 1233 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
-  start_css();
+//@line 1301 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1237 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1304 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var menuitem = aEvent.originalTarget;
   if (!menuitem.hasAttribute("panel"))
     return;
@@ -2241,7 +2321,7 @@ function IgnoreWord()
   sc.ignoreWord();
 }
 
-//@line 1439 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1506 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 function OpenCharInsertionDialog()
 {
   var w = null;
@@ -2255,7 +2335,7 @@ function OpenCharInsertionDialog()
    window.openDialog("chrome://bluegriffon/content/dialogs/insertChars.xul","_blank",
                      "chrome,modal=no,titlebar");
 }
-//@line 1453 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1520 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var gDummySelectionStartNode = null;
@@ -2393,7 +2473,6 @@ function MarkSelectionInAce(aAceEditor)
   aAceEditor.replace("");
 
   aAceEditor.gotoLine(startRow);
-  //bespinEditor.getSession().setValue(source.replace(/\-\-BG\-\-/g, ""));
   selection.setSelectionRange({ start: { row: startRow, column: startColumn },
                                 end:   { row: endRow,   column: endColumn } });
   aAceEditor.reset();
@@ -2422,7 +2501,7 @@ function UseAceTheme(aEvent)
   aceIframe.contentWindow.useTheme(theme);
 }
 
-//@line 1649 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1715 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 function SaveCurrentTabLocation()
 {
@@ -2452,3 +2531,9 @@ function SaveTabs()
   }
   catch(e) {}
 }
+
+function CreateOrUpdateTableOfContents()
+{
+  window.openDialog("chrome://bluegriffon/content/dialogs/insertTOC.xul","_blank",
+                    "chrome,modal,titlebar");
+}
