@@ -1,7 +1,9 @@
 /*
-//@line 38 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/amContentHandler.js"
+//@line 38 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/amContentHandler.js"
 */
 
+"use strict";
+
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
