@@ -1,5 +1,5 @@
 /*
-//@line 38 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/amWebInstallListener.js"
+//@line 38 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/amWebInstallListener.js"
 */
 
 /**
@@ -9,6 +9,8 @@
  * confirmation when all the add-ons have been downloaded.
  */
 
+"use strict";
+
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
@@ -17,6 +19,8 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
 Components.utils.import("resource://gre/modules/Services.jsm");
 
+const URI_XPINSTALL_DIALOG = "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul";
+
 // Installation can begin from any of these states
 const READY_STATES = [
   AddonManager.STATE_AVAILABLE,
@@ -167,8 +171,19 @@ Installer.prototype = {
     args.installs = this.downloads;
     args.wrappedJSObject = args;
 
-    Services.ww.openWindow(this.window, "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul",
-                           null, "chrome,modal,centerscreen", args);
+    try {
+      Services.ww.openWindow(this.window, URI_XPINSTALL_DIALOG,
+                             null, "chrome,modal,centerscreen", args);
+    } catch (e) {
+      this.downloads.forEach(function(aInstall) {
+        aInstall.removeListener(this);
+        // Cancel the installs, as currently there is no way to make them fail
+        // from here.
+        aInstall.cancel();
+      }, this);
+      notifyObservers("addon-install-cancelled", this.window, this.url,
+                      this.downloads);
+    }
   },
 
   /**
