@@ -1,8 +1,10 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-//@line 41 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 41 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/nsBlocklistService.js"
 */
 
+"use strict";
+
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
@@ -70,7 +72,7 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function bls_gABI() {
   catch (e) {
     LOG("BlockList Global gABI: XPCOM ABI unknown.");
   }
-//@line 119 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 121 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/nsBlocklistService.js"
   return abi;
 });
 
@@ -584,7 +586,7 @@ Blocklist.prototype = {
   },
 
   /**
-//@line 681 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 683 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/nsBlocklistService.js"
    */
 
   _loadBlocklistFromFile: function(file) {
@@ -943,20 +945,21 @@ Blocklist.prototype = {
           restartApp();
 
         Services.obs.notifyObservers(self, "blocklist-updated", "");
-        Services.obs.removeObserver(arguments.callee, "addon-blocklist-closed");
+        Services.obs.removeObserver(applyBlocklistChanges, "addon-blocklist-closed");
       }
 
       Services.obs.addObserver(applyBlocklistChanges, "addon-blocklist-closed", false)
 
+      function blocklistUnloadHandler(event) {
+        if (event.target.location == URI_BLOCKLIST_DIALOG) {
+          applyBlocklistChanges();
+          blocklistWindow.removeEventListener("unload", blocklistUnloadHandler);
+        }
+      }
+
       let blocklistWindow = Services.ww.openWindow(null, URI_BLOCKLIST_DIALOG, "",
                               "chrome,centerscreen,dialog,titlebar", args);
-
-      blocklistWindow.addEventListener("unload", function(event) {
-        if(event.target.location == URI_BLOCKLIST_DIALOG) {
-          applyBlocklistChanges();
-          blocklistWindow.removeEventListener("unload", arguments.callee);
-        }
-      },false)
+      blocklistWindow.addEventListener("unload", blocklistUnloadHandler, false);
     });
   },
 
