@@ -1,7 +1,7 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* vim: set ts=2 et sw=2 tw=80: */
 /*
-//@line 46 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 47 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 */
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -98,6 +98,7 @@ const nsITimer = Components.interfaces.nsITimer;
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/DownloadLastDir.jsm");
 Components.utils.import("resource://gre/modules/DownloadPaths.jsm");
+Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
 
 /* ctor
  */
@@ -148,7 +149,7 @@ nsUnknownContentTypeDialog.prototype = {
   reallyShow: function() {
     try {
       var ir = this.mContext.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
-      var dwi = ir.getInterface(Components.interfaces.nsIDOMWindowInternal);
+      var dwi = ir.getInterface(Components.interfaces.nsIDOMWindow);
       var ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                          .getService(Components.interfaces.nsIWindowWatcher);
       this.mDialog = ww.openWindow(dwi,
@@ -238,7 +239,7 @@ nsUnknownContentTypeDialog.prototype = {
     var nsIFilePicker = Components.interfaces.nsIFilePicker;
     var picker = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
     var windowTitle = bundle.GetStringFromName("saveDialogTitle");
-    var parent = aContext.QueryInterface(Components.interfaces.nsIInterfaceRequestor).getInterface(Components.interfaces.nsIDOMWindowInternal);
+    var parent = aContext.QueryInterface(Components.interfaces.nsIInterfaceRequestor).getInterface(Components.interfaces.nsIDOMWindow);
     picker.init(parent, windowTitle, nsIFilePicker.modeSave);
     picker.defaultString = aDefaultFile;
 
@@ -268,9 +269,13 @@ nsUnknownContentTypeDialog.prototype = {
                             .getService(Components.interfaces.nsIDownloadManager);
     picker.displayDirectory = dnldMgr.userDownloadsDirectory;
 
+    var relatedURI = null;
+    if (aContext.document)
+      relatedURI = aContext.document.documentURIObject;
+
     // The last directory preference may not exist, which will throw.
     try {
-      var lastDir = gDownloadLastDir.file;
+      var lastDir = gDownloadLastDir.getFile(relatedURI);
       if (isUsableDirectory(lastDir))
         picker.displayDirectory = lastDir;
     }
@@ -299,7 +304,7 @@ nsUnknownContentTypeDialog.prototype = {
       var newDir = result.parent.QueryInterface(Components.interfaces.nsILocalFile);
 
       // Do not store the last save directory as a pref inside the private browsing mode
-      gDownloadLastDir.file = newDir;
+      gDownloadLastDir.setFile(relatedURI, newDir);
 
       result = this.validateLeafName(newDir, result.leafName, null);
     }
@@ -337,7 +342,7 @@ nsUnknownContentTypeDialog.prototype = {
 
     var createdFile = DownloadPaths.createNiceUniqueFile(aLocalFile);
 
-//@line 397 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 403 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
     return createdFile;
   },
@@ -411,7 +416,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files.
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 491 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 497 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
       if (shouldntRememberChoice) {
         rememberChoice.checked = false;
         rememberChoice.disabled = true;
@@ -529,8 +534,17 @@ nsUnknownContentTypeDialog.prototype = {
       else
         typeString = mimeInfo.MIMEType;
     }
-
-    type.value = typeString;
+    // When the length is unknown, contentLength would be -1
+    if (this.mLauncher.contentLength >= 0) {
+      let [size, unit] = DownloadUtils.
+                         convertByteUnits(this.mLauncher.contentLength);
+      type.value = this.dialogElement("strings")
+                       .getFormattedString("orderedFileSizeWithType", 
+                                           [typeString, size, unit]);
+    }
+    else {
+      type.value = typeString;
+    }
   },
 
   _blurred: false,
@@ -551,12 +565,12 @@ nsUnknownContentTypeDialog.prototype = {
   // Returns true if opening the default application makes sense.
   openWithDefaultOK: function() {
     // The checking is different on Windows...
-//@line 641 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 656 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     // On other platforms, default is Ok if there is a default app.
     // Note that nsIMIMEInfo providers need to ensure that this holds true
     // on each platform.
     return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 646 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 661 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // Set "default" application description field.
@@ -577,9 +591,9 @@ nsUnknownContentTypeDialog.prototype = {
 
   // getPath:
   getPath: function (aFile) {
-//@line 669 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 684 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return aFile.path;
-//@line 671 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 686 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
   },
 
   // initAppAndSaveToDiskValues:
@@ -809,7 +823,7 @@ nsUnknownContentTypeDialog.prototype = {
         // for the file to be saved to to pass to |saveToDisk| - otherwise
         // we must ask the user to pick a save name.
 
-//@line 914 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 929 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
         // see @notify
         // we cannot use opener's setTimeout, see bug 420405
@@ -864,13 +878,13 @@ nsUnknownContentTypeDialog.prototype = {
   // Retrieve the pretty description from the file
   getFileDisplayName: function getFileDisplayName(file)
   {
-//@line 982 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 997 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     return file.leafName;
   },
 
   // chooseApp:  Open file picker and prompt user for application.
   chooseApp: function() {
-//@line 1030 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1045 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
     var nsIFilePicker = Components.interfaces.nsIFilePicker;
     var fp = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(nsIFilePicker);
@@ -887,7 +901,7 @@ nsUnknownContentTypeDialog.prototype = {
                    createInstance(Components.interfaces.nsILocalHandlerApp);
       localHandlerApp.executable = fp.file;
       this.chosenApp = localHandlerApp;
-//@line 1047 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/nsHelperAppDlg.js"
+//@line 1062 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/nsHelperAppDlg.js"
 
       // Show the "handler" menulist since we have a (user-specified)
       // application now.
