@@ -1,4 +1,4 @@
-//@line 2 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/app/profile/bluegriffon-prefs.js"
+//@line 2 "/home/glazou/trees/bg1.1/bluegriffon/app/profile/bluegriffon-prefs.js"
 
 pref("toolkit.defaultChromeURI", "chrome://bluegriffon/content/xul/bluegriffon.xul");
 pref("browser.chromeURL", "chrome://bluegriffon/content/xul/bluegriffon.xul");
@@ -10,9 +10,9 @@ pref("bluegriffon.singletonWindowType", "bluegriffon");
 // see https://developer.mozilla.org/en/XUL/prefwindow
 pref("browser.preferences.instantApply", true);
 
-//@line 16 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/app/profile/bluegriffon-prefs.js"
+//@line 16 "/home/glazou/trees/bg1.1/bluegriffon/app/profile/bluegriffon-prefs.js"
 pref("toolbar.customization.usesheet", false); // false otherwise
-//@line 18 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/app/profile/bluegriffon-prefs.js"
+//@line 18 "/home/glazou/trees/bg1.1/bluegriffon/app/profile/bluegriffon-prefs.js"
 
 /* debugging prefs */
 pref("browser.dom.window.dump.enabled", false);
@@ -21,9 +21,10 @@ pref("javascript.options.strict", false);
 pref("nglayout.debug.disable_xul_cache", true);
 pref("nglayout.debug.disable_xul_fastload", true);
 
-pref("general.useragent.extra.mybrowser", "bluegriffon/1.1.1");
+pref("general.useragent.extra.mybrowser", "bluegriffon/1.2.1");
 pref("intl.locale.matchOS", true);
 
+pref("extensions.update.autoUpdateDefault", true);
 pref("extensions.update.enabled", false);
 pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
