@@ -1,4 +1,6 @@
-//@line 37 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/content/eula.js"
+//@line 37 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/content/eula.js"
+
+"use strict";
 
 function Startup() {
   var bundle = document.getElementById("extensionsStrings");
