@@ -1,4 +1,4 @@
-//@line 39 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/extensions/content/list.js"
+//@line 39 "/home/glazou/trees/bg1.1/toolkit/mozapps/extensions/content/list.js"
 
 const kXULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
 const kDialog = "dialog";
@@ -38,6 +38,8 @@ const kDialog = "dialog";
  * result:  The dlgtype of button that was used to dismiss the dialog. 
  */
 
+"use strict";
+
 var gButtons = { };
 
 function init() {
